pitchtools.is_pitch_class_octave_number_string
==============================================

.. autofunction:: abjad.tools.pitchtools.is_pitch_class_octave_number_string.is_pitch_class_octave_number_string
